@@ -1,12 +1,12 @@
 package App::freq ;  
-our $VERSION = '0.123' ; 
-our $DATE = '2024-03-09T22:47+09:00' ; 
+our $VERSION = '0.124' ; 
+our $DATE = '2024-03-15T09:37+09:00' ; 
 
 =encoding utf8
 
 =head1 NAME
 
-App::freq
+App::freq The command `freq' counts how many different content of each line appears, with various options.
 
 =head1 SYNOPSIS
 
